function  estimation_of_multicyclones
clear
clc
% Created by Carlos E. Sanchez P. (May 2012)
%The program requires some parameters like Pressure (P), Nominal diameter
%(DN), ratio of liquid in the inlet gas(Rho_g), density of the liquid in
%the gas (Rho_l), superficial tension of the liquid (sigma), viscosity (mu)and droplet
%distribution
P = 120; % Working pressure in bar
%THE NOMINAL DIAMETER OF THE INLET PIPE MUST BE IN THE RANGE OF
%20<=DN<=900 (According to standard DN)
DN = 300; % Nominal diameter in mm
liq = 0.02; % Ratio of liquid in the inlet gas in volumetric percentage
Rho_g = 113.3; % Density of the gas in kg/m3 (It is strongly influenced by P
Rho_l = 800; % Density of the liquid in kg/m3 
sigma = 22; % Approx. surface tension value for non-polar hydrocarbons in dy/cm at 20 C
mu = 0.015750; % viscosity of the gas feed at 20 C in cP.
mu_L= 3.2; % Viscosity of the liquid at 20 C in cP.
PM_g=17.61; % Approximate molecular gas weight
cp_g=3.213; % Approx in kJ/(kgC)
% Conversion into SI units
sigma=sigma*1E-03; % in N/m
mu=mu*1E-03; % in Pa.s
mu_L=mu_L*1E-03; %Pa.s
dist_rel = [0 0.3 0.62 1 1.5 2.9; 0 0.05 0.25 0.5 0.75 1.0]; % Relative droplet distribution
% Now, it is required to introduce the maximum velocity at the inlet pipe
% according to the pipe nominal diameter. 
V_matrix=[20 25 40 50 80 100 125 150 200 250 300 350 400 450 500 600 650 700 750 800 850 900; 2 2 2 2 2 5 5 5 5 5 7 7 7 7 7 8 8 8 8 8 12 12];
%% Estimation of the inlet maximum velocity (Vel_max) in m/s. pos corresponds
%to the position on the row
[Vel,pos] = min(abs(V_matrix(1,:)-DN));
Vel_inlet = V_matrix(2,pos);

%% Determination of the outside diameter.
DN_matrix=[20 25 40 50 80 100 125 150 200 250 300 350 400 450 500 600 650 700 750 800 850 900; 26.7 33.4 48.3 60.3 88.9 114.3 141.3 168.3 219.1 273.1 323.9 355.6 406.4 457.2 508 609.6 660.4 711.2 762 812.8 863.6 914.4];
[d,pos_2]= min(abs(DN_matrix(1,:)-DN));
d_pipe_o = DN_matrix(2,pos_2);
%% Now, it is required to determine the nominal pressure, we have an
% equation and the pressure according to ANSI standards.  So, it will be
% used the highest pressure determined by both criteria.
Pw = P*14.5-14.5; % Working pressure in psig
% According to Seider et al (2004) if 0=<Pw<5 psig the nominal pressure (Pn) is
% 10 psig.  In our case, the nominal pressure corresponds to 20 bar (276
% psig), according to the minimum ANSI value. For values between 10 and
% 1000 psig we use the following equation.
if Pw<=5 && Pw>=0
    Pcr = 10/14.5+14.5; % in bar
end
if Pw<10 && Pw>5
        Pcr = 15/14.5+14.5; % in bar
end
fs=1.4; % It's a safety factor to avoid potential accidents
if Pw<=1000 && Pw>=10 
    Pcr = ((exp(0.60608+0.91615*log(Pw)+0.0015655*(log(Pw))^2))/14.5+14.5)*fs; % in bar
else
    Pcr = 1.1*fs*P;
end
% log in Matlab is ln while log10 means log
% Pressure matrix according tom the ANSI criterium
P_matrix = [20 50 100 150 250 420; 150 300 600 900 1500 2500];
[P_ansi,pos3]= min(abs(P_matrix(1,:)-P));
if P_matrix(1,pos3)<P
    P_ansi = P_matrix(1,pos3+1);
    ansi = P_matrix (2, pos3+1);
else
    P_ansi = P_matrix(1,pos3);
    ansi = P_matrix (2,pos3);
end
% Determination of the nominal pressure
if P>=420
    Pn = P*1.1;
else
    if P_ansi>Pcr
        Pn = P_ansi;
    else
        Pn = Pcr;
    end
end
%% Determination of the volumetric flow rate of gas (Q) in m3/s
% (All following values corresponds to the common chamber which contains the
% complete set of cyclones)
Sp=14400; % Stress allowance in the pipe in psig
Ep=1; % Joint efficiency, usually equal to 1.
t_pipe = ((Pn*14.5-14.5)*(d_pipe_o)/(2*Sp*Ep)); % Approx pipe thickness in mm
d_pipe_i = (d_pipe_o - 2*t_pipe)*1E-03; % in m
A_pipe_i = pi*(d_pipe_i)^2/4; % in m2
Q = Vel_inlet*A_pipe_i; % The global volumetric flow rate in m3/s
m_g = Rho_g*Q*(100-liq)/100; % Mass gas flow rate in kg/s
m_l = Rho_l*Q*(liq)/100; % Liquid gas flow rate in kg/s
%% Estimating the chamber dimensions
Ks_r=0.25; % According to HAT International brochure for demister separators
V_ch_m=Ks_r*((Rho_l-Rho_g)/Rho_g)^0.5; % Maximum velocity recommended in the multicyclone chamber.
A_ch_m=Q/V_ch_m; % Minimum recommended Internal area of the chamber
D_ch_m=(A_ch_m*4/pi)^0.5;
V_in_min=10; % Minimum recommended velocity at the cyclone inlet in m/s
% since the total internal area of cyclones corresponds to that value for a
% single one. We can estimate the maximum recommended velocity for a Ks
% maximum of 0.25
Dc_eq=(4*A_ch_m/pi)^0.5;
b_eq=0.2*Dc_eq; %Equivalent cyclone inlet pipe diameter for a single configuration
A_in_eq=pi*b_eq^2/4; %Equivalent cyclone inlet pipe area for a single configuration
V_in_max=Q/A_in_eq; % Maximum recommended velocity according to HAT international
if V_in_max<20
V_in_max=20; % Selecting the maximum recommended velocity
end
V_in_max=20; % Selecting the maximum recommended velocity
V_in=V_in_min:1:V_in_max; % Creating an array with different velocities
j_max=length(V_in); % Maximum counter of the loop
j_r=20; % Array index which corresponds to V_in=30m/s (Maximum recommended according to (Hoffmann & Stein, 2008)
if j_r>=j_max;
    j_r=j_max; % In the case
end
%% Iteration estimating the number of cyclones in parallel
for j=1:j_max
Dc=0.1524; % Standard cyclone diameter for Stairmand HE geometry 
b=0.2*Dc; % Maximum diameter of the cyclone inlet pipe
A_in=pi*b^2/4; % Inlet cyclone area in m2
Qc(j)=V_in(j)*A_in; % Approximate Volumetric flow per each cyclone.
nc(j)=ceil(Q/Qc(j)); % Approximate number of cyclones (integer number)
Qc(j)=Q/nc(j); % Cyclone volumetric flow rate
nc_cost(j)=nc(j);
A_ch=nc(j)*pi*Dc^2/4; % Transversal area of the chamber
V_ch=Q/A_ch;  % Velocity in the common cyclonic separator chamber
m_g_c=m_g/nc(j); m_l_c=m_l/nc(j); % Gas and liquid flow rates per cyclone
%% Determination of the mean droplet size 
%(It is assumed that the droplet will be the same in each cyclone. 
% Therefore,it is assumed that the droplet distribution corresponds at
% inlet chamber pipe.
Re_inlet=Rho_g*V_in(j)*b/(mu); %Reynolds number at the inlet pipe, viscosity converted into Pa.s
We_inlet=Rho_g*(V_in(j))^2*b/(sigma); %Weber number, surface tension converted into N/m
x_Sa=(1.91*b*(Re_inlet)^0.1/(We_inlet)^0.6*(Rho_g/Rho_l)^0.6)*1E06; % Sauder mean droplet in micro-m
x_med=1.42*x_Sa; % Mean droplet size in micro-m
x_max=(b*4.5*(sigma/(Rho_g*V_in(j)^2*b))^0.6*(Rho_g/Rho_l)^0.4)*1E06; %Expected maximum droplet size according to Campbell (2004)
if x_med>x_max;
    x_med=x_max/dist_rel(1,6); % In the case that x_med calculated is higher than x_max, the former is corrected
end
X = dist_rel(1,:)*x_med; % Expected size droplets at the inlet stream 
dist = [X ; dist_rel(2,:)]; % Expected distribution of droplets at the inlet stream
%% Determination of the cyclone dimensions
Rc=Dc/2;  % Preliminary cyclone radius
Dx=0.5*Dc; % Vortex diameter in m
Rx=Dx/2; % Vortex radius in m
Sc=0.5*Dc; % Outlet gas length
H=4*Dc;% Total length of the cyclone. 
Hc=2.5*Dc; % Length of the cone (In conical cyclones)
Hcs=Hc+Dc; % Length form the cyclone base to the inlet
Dd=0.375*Dc; % Length of the collected tray
Rd=Dd*0.5;
co=liq*Rho_l/(100*Rho_g); % Ratio between mass of liquid and gas at inlet
ps=b/(Rc); % Ratio between inlet pipe and cyclone radius in m
alpha=1/ps*(1-(1+4*((ps/2)^2-(ps/2))*(1-(1-ps^2)*(2*ps-ps^2)/(1+co))^0.5)^0.5); % Restriction coefficient
Rin=Rc-b/2; % Radius from cyclone centre until the medium of the inlet pipe
Rm=(Rx*Rc)^0.5; 
%% Set of velocities inside the cyclone.
Vt_w=V_in(j)*Rin/(alpha*Rc);
Vz_w=0.9*Qc(j)/(pi*(Rc^2-Rm^2)); % Axial wall velocity
V_x=Qc(j)/(pi*Dx^2/4); % Velocity at the gas outlet in m/s
%Reynolds at the cyclone body
% Determination of the relative roughness
ks=0.046; % in mm
ks=ks*1E-3; % in m
e_r=ks/Rc; % Relative roughness
if e_r<6E-04
    e_r=6E-04; % The relative roughness cannot be lower than that corresponding to smooth pipes
end
Ar=pi*(Rc^2-Rx^2+2*Rc*(H)+2*Rx*Sc); % Internal cyclone area
V_ratio=0; % initial assumption to determine Reynolds number
i_max=20; % maximum number of iterations
i=1; 
while i<=i_max;
% Determination of friction factors for air at the working gas conditions
Re_R=Rin*Rm*Vz_w*Rho_g/(H*mu*(1+(V_ratio)^2));
% It was used the friction factor for conical cyclones since that used for
% cylindrical tends to underestimate the frictions factor
f_sm=0.323*Re_R.^(-0.623); % for smooth surfaces
fr=(log((1.6/(e_r-0.000599))^2.38))^(-2)*(1+2.25E05/(Re_R.^2*(e_r-0.000599)^0.213))^(-1); % including relative roughness
f_air=f_sm+fr; % gas friction factor
f=f_air*(1+0.4*co^0.1); % Overall friction factor
Vt_CS=Vt_w*(Rc/Rx)/(1+f*Ar*Vt_w*(Rc/Rx)^0.5/(2*Qc(j)));
Vt_m=(Vt_w*Vt_CS)^0.5;
V_ratio=Vz_w/Vt_m; % Ratios in velocities used in determination of Reynolds
Re_R_c=Rin*Rm*Vz_w*Rho_g/(H*mu*(1+(V_ratio)^2)); %Reynolds calculated with the real volocity ratio
Re_error=abs(Re_R_c-Re_R)/Re_R_c;
if Re_error<0.005; % Acceptable discrepancy of 0.5%
    i_max=i; % To stop the iteration. 
end
i=i+1;
end
Re_R=Re_R_c;
Vr_CS=Qc(j)/(2*pi*Rx*Hcs); % Radial velocity at the inner vortex in m/s
x_fact=1;
x_50=(x_fact*(18*mu*0.9*Qc(j)/(2*pi*(Rho_l-Rho_g)*(Vt_CS)^2*(H-Sc)))^0.5)*1E06; % cut-point diameter in micro-m
% calculated by using the Barth's formula (Valid for Re_p <0.5)
Re_p=Rho_g*Vr_CS*x_50*1E-06/mu; %Particle Reynolds number
if Re_p>0.5;
    x_50=(5.18*(mu^0.375*Rho_g^0.25*Vr_CS^0.875)/((Rho_l-Rho_g)*Vt_CS^2/Rx)^0.625)*1E06; % In the case that Barth's formula isn't applicable
end
%% Determination of the separation efficiency
m=3; %parameter used to determine the efficiency
for i=2:6
    n(i)=(1+(x_50/dist(1,i))^m)^(-1); %Efficiency per segment
end
F=[0 0.05 0.2 0.25 0.25 0.25];
n_sep_1=sum(n.*F); % Overall separation efficiency.  The term (.*) corresponds 
%to an array multiplication where figures from the same position are
%multiplied.
% It is also important to determine the efficiency for the smallest
% droplets (Especially if they are smaller than 20 micro-m)
a=1; a_max=5;
while a<=a_max;
    n_small(j)=sum(n(a).*F(a))/ sum(F(a));% Efficiency for the smallest droplets
    droplet_s=dist(1,a); % Smallest droplet size registered
    if droplet_s > 20 % Taken the smallest droplet acceptable as 20 micro-m
        a_max=a;
    end
    a=a+1;
end
% We should determine if the "Saltation" phenomenon is present.
if co>0.5
    co_k=0.5;
else
    co_k=co;
end
k=0.07-0.16*log(co_k);
Co_L = 0.07-0.16*(x_50/x_med)*(10*co_k)^k; % Mass loading limit
% If the liquid loading (co) is higher than Co_L the efficiency changes
if co>Co_L;
    n_sep(j)=(1-Co_L/co)+(Co_L/co)*n_sep_1;
else
    n_sep(j)=n_sep_1;
end

%% Effect the re-entrainment in the efficiency
e=0.000046; % absolute roughness in m
Re_l=4*m_l_c/(pi*Dc*mu_L);
f_l_w=0.25*(log10(e/(3.7*Dc)+ 5.74/(Re_l^0.9)))^(-2);% Friction factor between liquid and pipe wall
beta=45; % flow inclination regarding to the horizontal in degrees (approximation)
beta=beta*pi/180; % flow angle in radians.
g=9.81; % gravity acceleration in m/s2
options = optimset('Display','off'); % To optimise the iteration
F=@(y)32*sin(beta)/(pi^2*Dc^5*(1-y))*(m_l_c^2*f_l_w/(Rho_l*(1-y)^2)-m_g_c^2*0.046*(4*m_g_c/(pi*mu*y^0.5*Dc))^(-0.2) /(Rho_g*y^(5/2)))-(Rho_l-Rho_g)*g;
% The interfacial friction factor (for the gas in this case) was
% substituted into eq. F
eps=fzero(F,[0.00001 0.999999],options); % Determination of te gas void fraction (eps)
delta=Dc*(1-(eps)^0.5)/2; % the approximate liquid film thickness
v_l=4*m_l_c/(Rho_l*pi*Dc^2*(1-eps)); % Mean velocity of liquid film in m/s
v_g=4*m_g_c/(Rho_g*pi*Dc^2*eps); % Mean velocity of the gas
Re_f=Rho_l*v_l*delta/mu_L; % Liquid Reynolds number by means of liquid film thickeness
N_v=mu_L/(Rho_l*sigma*(sigma/(g*(Rho_l-Rho_g)))^0.5)^0.5;  % Computing the viscous number
N_re=(mu_L*v_g/(sigma))*(Rho_g/Rho_l)^0.8/(N_v^0.4*Re_f^(-1/3)); % Reentrainment number
if N_re<0.25
    n_re(j)=1; 
else
n_re(j)= -0.1429*N_re + 1.0357;
end
n_g(j)=n_re(j)*n_sep(j)*100; % Overall cyclone efficiency considering both separation and reentrainment
t_res(j)=H/(v_l*sin(beta)); % Liquid residence time in s
%% Determination of the pressure drop
p_body=f*Ar*Rho_g*(Vt_CS*Vt_w)^1.5/(1.8*Qc(j)); % pressure drop in the cyclone body in Pa
p_x=0.5*Rho_g*V_x^2*(2+(Vt_CS/V_x)^2+3*(Vt_CS/V_x)^(4/3)); % Pressure drop in the vortex core in Pa
if V_in>Vel_inlet
    p_acc=(1+co)*Rho_g*(V_in(j)^2-V_ch^2)/2; % Determing pressure losses in the case of acceleration
else
    p_acc=0;
end
p_drop=p_body+p_x+p_acc; % Pressure drop in Pa
p_drop_m(j)=p_drop/100; % Pressure drop in mbar
p_drop_w(j)=p_drop/9.802; % Pressure drop in cm H2O
end
%% Determining the maximum recommended velocity taking into consideration re-entrainment and separation efficiency
j=1;
while j<j_max
    V_in_max(j)=V_in(j);
    if n_re(j)<1 || n_g(j)<99.5 % The maximum allowable cyclone inlet velocity for a minimum efficiency 99.9% and without re-entrainmet 
        j_max=j-1;
    end
    j=j+1;
end
V_in_max=V_in(j_max);
V_in=V_in_min:1:V_in_max; % Creating an array with different velocities
j_max
j_r
if j_r>=j_max;
    j_r=j_max; % In the case
end
j_r
n_re(j_max)
n_g(j_max)
%% Estimating the chamber dimensions for the maximum and minimum number of cyclones
% We need to estimate the thickness of each cyclone.
t_c = ((Pn*14.5-14.5)*(Dc*1E3)/(2*Sp*Ep)); % Approx cyclone thickness in mm
Dc_o = Dc + 2*t_c*1E-03; % in m
% Estimation of cyclones pitch
pitch=1.2*Dc_o; % According to (Karno & Ajib 2004)
if pitch<80E-3 % Minimum pitch (in mm) according to Shell (2002)
    pitch=80E-3;
end
pitch
Dc_o
% Estimating weight per cyclone
Rho_m=7850; %Steel density in kg/m^3
W_cy=Rho_m*pi*(Dc_o^2-Dc^2)*H/4;
for j=1:j_max
A_ch_ar(j) = (pitch/2)^2*pi*nc(j); % it is supposed a separation among he cyclones at least 80 mm ('Shell', 2002)
D_ch(j)=(4*A_ch_ar(j)/pi)^0.5;
ks_c(j)=(Q/A_ch_ar(j))*(Rho_g/(Rho_l-Rho_g))^0.5; % Load factor calculated.
% adjusted by increments of 6 inches (154 mm aprox).
D_ch(j) = (ceil(D_ch(j)/0.154)*0.154); %in m
A_ch_ar(j)=pi*D_ch(j)^2/4; % Correcting the transversal area

h=(Q*liq/100)*t_res(j)/A_ch_ar(j); % Estimation of liquid height inside of the vessel
if h<0.8
    h=0.8; % Adjusting the length of the liquid column (Minimum, according to Shell 2002)
end
Lss(j)=(H+h+0.90+0.2*D_ch(j)+d_pipe_o*1E-03); % Using the minimum length supplied by Shell (2002) (Selecting the most conservative option)
if Lss(j)<1.0*D_ch(j);
    Lss(j)=1.0*D_ch(j); % to give a security margin
end
% Determination of the thickness of the vessel (t). Firstly, it is determine by
% means of pressure and then it is taken into consideration the wind effect.
E = 0.85; % The joint efficiency
S = 138; % Maximum allowable stress in MPa.
C = 1.5; % Corrosion allowance in mm (It should be higher in more corrosive media)
tp = Pn*0.1*D_ch(j)*1000/(2*S*E-1.2*Pn*0.1); % in mm
if (Lss(j)/D_ch(j))^2/(Pn*14.5-14.5)<= 10 && (Lss(j)/D_ch(j))^2/(Pn*14.5-14.5)>= 1.34
    t(j) = tp*(0.75+0.22*E*(Lss/Di)^2/(P*14.5-14.5))+C;
else
    t(j) = tp + C;
end
% Introduction of the minimum vessel thickness according to the diameter
% According to Seider et al (2004), we have:
if D_ch(j)<1 && t(j)<5
    t(j)=5;
if D_ch(j)>=1 && D_ch(j)<2 && t(j)<7
    t(j)=7;
    if D_ch(j)>=2 && D_ch(j)<2.5 && t(j)<9
        t(j)=9;
        if D_ch(j)>=2.5 && D_ch(j)<3 && t(j)<10
            t(j)=10;
            if D_ch(j)>=3 && D_ch(j)<=3.5 && t(j)<12
                t(j)=12;
            end
        end
    end
end
% the minimum thickness of the following intervals are determined following
% the sequence before.
if D_ch(j)>3.5
    for i=1:10
        Dmin=3.0+i*0.5;
        Dmax=3.5+i*0.5;
        tmin=12+(1+2*i)+(-1)^(i);
        if D_ch(j)>Dmin && D_ch(j)<=Dmax && tmin>t(j)
            t=tmin;
        end
    end
end
end
% The wind effect is considered only in the range which appears above.
% the thickness is adjusted according to standard increments.
if t(j)<=50.8
    t(j)=ceil(t(j)/3.175)*3.175;
else
    t(j)=ceil(t(j)/6.35)*6.35;
end
% Determination of the vessel weight without internals
We(j)=(pi*(D_ch(j)*100/2.54+t(j)/(10*2.54))*(Lss(j)*100/2.54+0.8*D_ch(j)*100/2.54)*t(j)/(10*2.54)*0.284)*0.454;% in kg
We(j)=0.032*D_ch(j)*1000*t(j)*Lss(j);
% On the book by Campbell appears a simpler formula but it overestimates
% the weight when Lss/D_ch is higher than 5 and it possibly underestimates
% the weight when Lss/D_ch is lower than 3
% Determination of the weight of nozzles and internals
% To determine the weight of the cyclones we can use the approximate
% density of steel (7850 kg/m3) and its dimensions 
% Weight of internals according to the internal diameter of the vessel
Rho_m=7850; % Approximate density of steel
Wi(j)=W_cy*nc(j); % It is determined the cyclone volume and it's multiplied by the density
    Wi(j) = ceil(Wi(j));
    
% Weight of the nozzles (Wn).The software determines which nozzle weight (Wn) matrix
% DN>600 mm are out of range to compute the weight of the nozzles.
% corresponds to the ANSI class, determined before
ANSI = [150 300 600 900];
for i=1:4
    if ANSI(i)==ansi;
        k=i;
    else
        i=i+1;
    end
end
DN_array = [50 75 100 150 200 250 300 350 400 450 500 600]; % Array of the established DN for estimating Wn
% cat allows creating 3D arrangements
Wn_matrix = cat(4,[DN_array; 4 7 11 20 29 43 61 75 97 150 194 267],[DN_array; 5 11 18 32 50 66 100 129 168 277 321 513],[DN_array; 7 18 27 54 79 129 165 233 315 424 564 823],[DN_array; 13 20 34 70 118 170 249 351 437 625 767 1379]);
% Then, it will be estimate the weight of the nozzles taking into
% consideration the closest value of (DN, immediately higher)
if DN<50 || DN>600 
    Wn(j)=0.08*We(j); % It's an approximation made by Sinnot et al (2005)
else
for i=1:4
    if i==k
[Wn,pos4]= min(abs(Wn_matrix(1,:,i)-DN));
if Wn_matrix(1,pos4,i)<DN
   Wn(j) = Wn_matrix(2,pos4+1,i);
else
    Wn(j) = Wn_matrix(2,pos4,i);
end
    else
        i=i+1;
    end
end
end
%% Calculation of the total vessel weight
W_tot(j)=We(j)+Wi(j)+Wn(j); % in kg
end
%% Determination of the purchase cost by Seider et al (2010) eq (Vessel), based on
% January 2007's prices and cyclonic set by Couper et al (2003).
CEPCI_2006=500;CEPCI_2000=391.1;CEPCI_2011 = 590.8;CEPCI_2001=394; CEPCI_2002=396; % Chemical Engineering indexes 
% By using the pressure factor provided by Seider (Lecture slides)
fp=0.9803+0.018*(Pn*14.7/100)+0.0017*(Pn*14.7/100)^2;
Vc=pi*Dc^2/4*H; % Approximate volume of each cyclone
if Vc>=0.06
C_c_unit=Vc*10^(3.6298-0.4991*log10(Vc)+0.04110*(log10(Vc))^2)*CEPCI_2011/CEPCI_2000; % Cost per each cyclones (Turton et al, 2009)
else
    C_c_unit=1190*(Vc/0.06)^0.6*CEPCI_2011/CEPCI_2002;
end
FBM_c=1.4; % Bare module factor used for cyclones (Couper et al, 2010), which includes installation costs
for j=1:j_max
% the range of the equation is from 4200 lb(1906 kg) to 1000000 lb (454000
% kg). Ladders and platforms are between 0.9<Di<6.4 and 3.7<Lss<12.2
C_b_Seider = (exp(7.0132+0.18255*log((W_tot(j))/0.454)+0.02297*(log((W_tot(j))/0.454))^2)); 
if D_ch(j)<0.9 || Lss(j)<6.4 || D_ch(j)>6.4 || Lss(j)>12.2
C_a_Seider = (exp(7.0132+0.18255*log(0.05*W_tot(j)/0.454)+0.02297*(log(0.05*W_tot(j)/0.454))^2)); % Value to corresponds to 5% of the overall weight
else
C_a_Seider = 361.8*(D_ch(j)/0.3048)^0.7396*(Lss(j)/0.3048)^0.70684; %Di and Lss in the equation are converted into ft.
end
C_vessel(j) = (C_a_Seider + C_b_Seider)*CEPCI_2011/CEPCI_2006;
%Determination of the cyclones costs
% It is required the volumetric flow rate in each cyclone by means of scfm
%Therefore, we can estimate this by using the following equation:
% The formula to determine the cyclone cost is in the range of 2 to 40 k scfm
C_cyclone(j)=C_c_unit*nc(j)*FBM_c;
C_sep(j)=C_vessel(j)+C_cyclone(j); % Total purchase cost of the separator (Excluding installation cost of cyclones)
end
%% Estimation of the bare module cost for the cyclonic unit
B1=2.5; B2=1.72; % Factors to determine the bare module factor in vertical vessel,(Turton et al, 1998)
Fm=1; % Factor for different materials
%Determination of the pressure factor to scale up the separator for higher
%pressures.
if Pn-1<3.7
    f_pres=1;
else
f_pres=0.5146+0.6838*log10(Pn-1)+0.2927*(log10(Pn-1))^2+0.0235*(log10(Pn-1))^6+0.002*(log10(Pn-1))^8;
end
C_sep_bm = C_sep*(B2+B1/(Fm*f_pres)); % Bare module cost of the cyclonic separator
%% Determination of the optimum cyclone by means of hypothetical energy consumption in 5 years
% and initial investment
R=8.314; % Ideal gas constant in kJ/(kgK)
n_p=0.925; % Polytropic efficiency of compressors. Taking from Bolland (2010)
N_g=0.36; % Efficiency of a gas turbine (the Brayton cycle). Taking from Bolland (2010)
C_power=0.297; % Cost per kWh in Norway in NOK. Taken from ('Statistics Norway', 2012) for energy intensive manufacturing
c_rate=6; % Currency rate between $ and NOK
period= 10; % Number of years
for j=1:j_max
    W_c(j) = Q*Rho_g*cp_g*293.15*(((P+(p_drop_m(j))*1E-3)/P)^(R/(cp_g*PM_g*n_p))-1); % Power required to compress gas due pressure drop
    W_t(j) = W_c(j)*8760*period/N_g; % Required Power produced in gas compression per annum
    C_e(j) = W_t(j)*C_power/c_rate; % Hypothetical electricy consuption in NOK
end
f_loc=1.2; % Location factor in Western Europe
C_tot=f_loc*C_sep_bm+C_e;
%Estimating the optimum velocity
[AC,j_op]=min(abs(C_e+C_sep_bm*f_loc)); % Estimating the counter in the array which gives the minimum cost
V_op=V_in(j_op); % The optimum velocity according to the trade-off between initial investment and pressure drop
plot(V_in,C_sep_bm*f_loc/1000,V_in,C_e/1000,'--',V_in,C_tot/1000),xlabel('Cyclone inlet velocity (m/s)'), ylabel('Cost (M$)'), legend('Cyclonic separator cost, including installation','Hypothetical re-compression cost in 10 years','Total cost'), grid on
if j_op>11;
    j_op=11; % The counter which corresponds to 20 m/s.
end
%% Summary of the vessel dimensions and f.o.b costs 
disp('      CYCLONIC GAS SCRUBBER DIMENSIONS (THE MOST COMPACT UNIT)     ');  
disp([' The diameter of the vessel (in m) is:  ',num2str(D_ch(j_r),3)]);
disp([' The height of the vessel (in m) is:    ',num2str(Lss(j_r),3)]);
disp([' The thickness of the vessel (in mm) is:   ', num2str(t(j_r),3)]);
disp([' The weight of the vessel (in kg), including cyclones and nozzles: ', num2str(W_tot(j_r),6)]);
disp([' The number of cyclones is:    ', num2str(nc(j_r),3)]);
disp([' Velocity at the cyclone inlet in (m/s)     ', num2str(V_in(j_r),2)]);
disp([' Estimated load factor(Ks) in (m/s):   ', num2str(ks_c(j_r),2)]);
disp([' The pressure drop (in mbar) is:    ', num2str(p_drop_m(j_r),4)]);
disp('   F.O.B VESSEL AND CYCLONES COST in US$   ');
if DN<50 || DN>600
    disp('THE WEIGHT OF NOZZLES CORRESPONDS TO AN APPROXIMATION')
end
if W_tot(j_r)>=1906 && W_tot(j_r)<=454000 
    if D_ch(j_r)<0.9 || D_ch(j_r)>6.4 || Lss(j_r)<3.7 || Lss(j_r)>12.2
       disp('THE COST OF LADDERS AND PLATFORMS IS A ROUGHT APPROXIMATION ACCORDING TO SEIDER el at eq')
    end
disp(['Purchase vessel cost, according to Seider et al (2010):  ', num2str(C_vessel(j_r),7)]);
else
    disp('THE VESSEL IS OUT OF RANGE ACCORDING TO SEIDER EQ (2010)')
end
if Dc>=0.05 && Dc<=3
    disp(['Cyclones cost, according to Smith (2005), including installation:    ' , num2str(C_cyclone(j_r),7)]);
else
     disp('THE CYCLONE GEOMETRY (THE INDIVIDUAL CYCLONE) IS OUT OF RANGE, CHOOSE ANOTHER BIGGER ')
end
if W_tot(j_r)>=1906 && W_tot(j_r)<=454000  
    disp([' Total purchase cost of the cyclonic unit:  ' , num2str(C_sep(j_r),7)]);
else
    disp('THE CYCLONIC UNIT IS OUT OF RANGE ')
end
disp(' BARE MODULE CYCLONIC UNIT COST (in US$), INCLUDING INSTALLATION AND EXCLUDING INTERNATIONAL FREIGHT AND CONTINGENCIES,  ');
disp('                                       ACCORDING TO THE GUTHRIE FACTORS                                      ');
if W_tot(j_r)>=1906 && W_tot(j_r)<=454000
disp(['Bare module cyclone cost in $:  ', num2str(C_sep_bm(j_r), 7)]);
end
disp('  CYCLONIC GAS SCRUBBER DIMENSIONS (THE OPTIMUM DESIGN ACCORDING TO THE TRADE-OFF BETWEEN INITIAL INVESTMENT AND PRESSURE DROP)    ');  
disp([' The diameter of the vessel (in m) is:  ',num2str(D_ch(j_op),3)]);
disp([' The height of the vessel (in m) is:    ',num2str(Lss(j_op),3)]);
disp([' The thickness of the vessel (in mm) is:   ', num2str(t(j_op),3)]);
disp([' The weight of the vessel (in kg), including cyclones and nozzles: ', num2str(W_tot(j_op),6)]);
disp([' The number of cyclones is:    ', num2str(nc(j_op),3)]);
disp([' Velocity at the cyclone inlet in (m/s)     ', num2str(V_op,2)]);
disp([' Estimated load factor (Ks) in (m/s):   ', num2str(ks_c(j_op),2)]);
disp([' The pressure drop (in mbar) is:    ', num2str(p_drop_m(j_op),4)]);
disp('   F.O.B VESSEL AND CYCLONES COST in US$   ');
if DN<50 || DN>600
    disp('THE WEIGHT OF NOZZLES CORRESPONDS TO AN APPROXIMATION')
end
if W_tot(j_op)>=1906 && W_tot(j_op)<=454000 
    if D_ch(j_op)<0.9 || D_ch(j_op)>6.4 || Lss(j_op)<3.7 || Lss(j_op)>12.2
       disp('THE COST OF LADDERS AND PLATFORMS IS A ROUGHT APPROXIMATION ACCORDING TO SEIDER el at eq')
    end
disp(['Purchase vessel cost, according to Seider et al (2010):  ', num2str(C_vessel(j_op),7)]);
else
    disp('THE VESSEL IS OUT OF RANGE ACCORDING TO SEIDER EQ (2010)')
end
if Dc>=0.05 && Dc<=3
    disp(['Cyclones cost, according to Smith (2005), including installation:    ' , num2str(C_cyclone(j_op),7)]);
else
     disp('THE CYCLONE GEOMETRY (THE INDIVIDUAL CYCLONE) IS OUT OF RANGE, CHOOSE ANOTHER BIGGER ')
end
if W_tot(j_op)>=1906 && W_tot(j_op)<=454000 
    disp([' Total purchase cost of the cyclonic unit:  ' , num2str(C_sep(j_op),7)]);
else
    disp('THE CYCLONIC UNIT IS OUT OF RANGE ')
end
disp(' BARE MODULE CYCLONIC UNIT COST (in US$), INCLUDING INSTALLATION AND EXCLUDING INTERNATIONAL FREIGHT AND CONTINGENCIES,  ');
disp('                                       ACCORDING TO THE GUTHRIE FACTORS                                      ');
if W_tot(j_op)>=1906 && W_tot(j_op)<=454000
disp(['Bare module cyclone cost in $:  ', num2str(C_sep_bm(j_op), 7)]);
end
disp('  CYCLONIC GAS SCRUBBER DIMENSIONS (MINIMUM PRESSURE DROP)    ');  
disp([' The diameter of the vessel (in m) is:  ',num2str(D_ch(1),3)]);
disp([' The height of the vessel (in m) is:    ',num2str(Lss(1),3)]);
disp([' The thickness of the vessel (in mm) is:   ', num2str(t(1),3)]);
disp([' The weight of the vessel (in kg), including cyclones and nozzles: ', num2str(W_tot(1),6)]);
disp([' The number of cyclones is:    ', num2str(nc(1),3)]);
disp([' Velocity at the cyclone inlet in (m/s)     ', num2str(V_in(1),2)]);
disp([' Estimated load factor (Ks) in (m/s):   ', num2str(ks_c(1),2)]);
disp([' The pressure drop (in mbar) is:    ', num2str(p_drop_m(1),4)]);
disp('   F.O.B VESSEL AND CYCLONES COST in US$   ');
if DN<50 || DN>600
    disp('THE WEIGHT OF NOZZLES CORRESPONDS TO AN APPROXIMATION')
end
if W_tot(1)>=1906 && W_tot(1)<=454000 
    if D_ch(1)<0.9 || D_ch(1)>6.4 || Lss(1)<3.7 || Lss(1)>12.2
       disp('THE COST OF LADDERS AND PLATFORMS IS A ROUGHT APPROXIMATION ACCORDING TO SEIDER el at eq')
    end
disp(['Purchase vessel cost, according to Seider et al (2010):  ', num2str(C_vessel(1),7)]);
else
    disp('THE VESSEL IS OUT OF RANGE ACCORDING TO SEIDER EQ (2010)')
end
if Dc>=0.05 && Dc<=3
    disp(['Cyclones cost, according to Smith (2005), including installation:    ' , num2str(C_cyclone(1),7)]);
else
     disp('THE CYCLONE GEOMETRY (THE INDIVIDUAL CYCLONE) IS OUT OF RANGE, CHOOSE ANOTHER BIGGER ')
end
if W_tot(1)>=1906 && W_tot(1)<=454000 
    disp([' Total purchase cost of the cyclonic unit:  ' , num2str(C_sep(1),7)]);
else
    disp('THE CYCLONIC UNIT IS OUT OF RANGE ')
end
disp(' BARE MODULE CYCLONIC UNIT COST (in US$), INCLUDING INSTALLATION AND EXCLUDING INTERNATIONAL FREIGHT AND CONTINGENCIES,  ');
disp('                                       ACCORDING TO THE GUTHRIE FACTORS                                      ');
if W_tot(1)>=1906 && W_tot(1)<=454000
disp(['Bare module cyclone cost in $:  ', num2str(C_sep_bm(1), 7)]);
end
