function  estimation_of_vertical_separator_mod_3
clear
clc
% Created by Carlos E. Sanchez P. (April 2012)
%The program requires some parameters like Pressure (P), Nominal diameter
%(DN), ratio of liquid in the inlet gas(Rho_g), density of the liquid in
%the gas (Rho_l) and thickness of the inlet pipe (Depending on material)
P = 80; % Working pressure in bar
%THE NOMINAL DIAMETER OF THE INLET PIPE MUST BE IN THE RANGE OF
%20<=DN<=900 (According to standard DN)
DN = 300; % Nominal diameter in mm
liq = 0.02; % Ratio of liquid in the inlet gas in %
Rho_g = 70.79; % Density of the gas in kg/m3 (It is strongly influenced by P
Rho_l = 800; % Density of the liquid in kg/m3 
% Now, it is required to introduce the maximum velocity at the inlet pipe
% according to the pipe nominal diameter. 
V_matrix=[20 25 40 50 80 100 125 150 200 250 300 350 400 450 500 600 650 700 750 800 850 900; 2 2 2 2 2 5 5 5 5 5 7 7 7 7 7 8 8 8 8 8 12 12];
%% Estimation of the inlet maximum velocity (Vel_max) in m/s. pos corresponds
%to the position on the row
[Vel,pos] = min(abs(V_matrix(1,:)-DN));
Vel_inlet = V_matrix(2,pos);

%% Determination of the outside diameter.
DN_matrix=[20 25 40 50 80 100 125 150 200 250 300 350 400 450 500 600 650 700 750 800 850 900; 26.7 33.4 48.3 60.3 88.9 114.3 141.3 168.3 219.1 273.1 323.9 355.6 406.4 457.2 508 609.6 660.4 711.2 762 812.8 863.6 914.4];
[d,pos_2]= min(abs(DN_matrix(1,:)-DN));
d_pipe_o = DN_matrix(2,pos_2);
%% Now, it is required to determine the nominal pressure, we have an
% equation and the pressure according to ANSI standards.  So, it will be
% used the highest pressure determined by both criteria.
Pw = P*14.5-14.5; % Working pressure in psig
% According to Seider et al (2004) if 0=<Pw<5 psig the nominal pressure (Pn) is
% 10 psig.  In our case, the nominal pressure corresponds to 20 bar (276
% psig), according to the minimum ANSI value. For values between 10 and
% 1000 psig we use the following equation.
if Pw<=5 && Pw>=0
    Pcr = 10/14.5+14.5; % in bar
end
if Pw<10 && Pw>5
        Pcr = 15/14.5+14.5; % in bar
end
fs=1.0; % It's a safety factor to avoid potential accidents
if Pw<=1000 && Pw>=10 
    Pcr = ((exp(0.60608+0.91615*log(Pw)+0.0015655*(log(Pw))^2))/14.5+14.5)*fs; % in bar
else
    Pcr = 1.1*fs*P;
end
% log in Matlab is ln while log10 means log
% Pressure matrix according tom the ANSI criterium
P_matrix = [20 50 100 150 250 420; 150 300 600 900 1500 2500];
[P_ansi,pos3]= min(abs(P_matrix(1,:)-P));
if P_matrix(1,pos3)<P
    P_ansi = P_matrix(1,pos3+1);
    ansi = P_matrix (2, pos3+1);
else
    P_ansi = P_matrix(1,pos3);
    ansi = P_matrix (2,pos3);
end
% Determination of the nominal pressure
if P>=420
    Pn = P*1.1;
else
    if P_ansi>Pcr
        Pn = P_ansi;
    else
        Pn = Pcr;   
end
%% Determination of the volumetric flow rate of gas (Q) in m3/s
Sp=14400; % Stress allowance in the pipe in psig
Ep=1; % Joint efficiency, usually equal to 1.
t_pipe = ((Pn*14.5-14.5)*(d_pipe_o)/(2*Sp*Ep)); % Approx pipe thickness in mm
d_pipe_i = d_pipe_o - 2*t_pipe; % in mm
A_pipe_i = pi*(d_pipe_i*1E-03)^2/4; % in m2
Q = Vel_inlet*A_pipe_i; % in m3/s
%% Determination of the Ks factor and maximum velocity in the separator.  

% Ks is 0.107 m/s when P is 1 bar but it is corrected for higher P (by fp)
%By using the Fabian et al (1993) data and according to a curve fitting, we
%have (Range 1 bar =< P =<80bar:
fp = -1.7386E-06*P^3+2.5581E-4*P^2-0.012529*P+1.005129;
if P > 80
    fp=0.75;
else
    fp=fp;
end
Ks = 0.107*fp;
V_max=Ks*((Rho_l-Rho_g)/Rho_g)^0.5;
%% Determination of internal diameter of the vessel (Di), then it is
Di = ((4*Q/(pi*V_max))^0.5)*1000; % in mm
% adjusted by increments of 6 inches (154 mm aprox).
Di = (ceil(Di/154)*154)*1E-3; %in m
%% Determination of the height of the vessel.  There, it is required to
%determine the height of liquid by using a residence time (tr)
tr = 10; % in min, according to Sinnot & Towler (2009)
h=(8.842E-4*(Q*liq/100)*tr/(Di)^2)*1000; % the parameter Q*liq represents the flow rate of liquid 
%According to NORSOK P-100, h should be higher than 100 mm, but according
%to Sinnot & Towler (2009) it should be al least 300 mm to ensure level
%control
if h < 300
    h=300;
else
    h=h;
end
% Lss is the height of the vessel (from seam to seam)
Lss = (h+Di*1000*1.5+400)/1000; % in m (According to Sinnot & Towler (2009))
if Lss<2
    Lss=2; % It's the minimum lenght recommended by Sinnot & Towler (2009)
end
%Lss should be adjusted acoording to slenderness ratio that is usually in the range
%of 2-5 but most authors recommend that the lowest limit should be 2.5
if Lss/(Di) < 2.5
    Lss = 2.5*Di;
else
    Lss = Lss;
end
%% Determination of the thickness of the vessel (t). Firstly, it is determine by
% means of pressure and then it is taken into consideration the wind effect.
E = 0.85; % The joint efficiency
S = 138; % Maximum allowable stress in MPa.
C = 1.5; % Corrosion allowance in mm (It should be higher in more corrosive media)
tp = Pn*0.1*Di*1000/(2*S*E-1.2*Pn*0.1); % in mm
if (Lss/Di)^2/(Pn*14.5-14.5)<= 10 && (Lss/Di)^2/(Pn*14.5-14.5)>= 1.34
    t = tp*(0.75+0.22*E*(Lss/Di)^2/(P*14.5-14.5))+C;
else
    t = tp + C;
end
% Introduction of the minimum vessel thickness according to the diameter
% According to Seider et al (2004), we have:
if Di<1 && t<5
    t=5;
if Di>=1 && Di<2 && t<7
    t=7;
    if Di>=2 && Di<2.5 && t<9
        t=9;
        if Di>=2.5 && Di<3 && t<10
            t=10;
            if Di>=3 && Di<=3.5 && t<12
                t=12;
            end
        end
    end
end
% the minimum thickness of the following intervals are determined following
% the sequence before.
if Di>3.5
    for i=1:10
        Dmin=3.0+i*0.5;
        Dmax=3.5+i*0.5;
        tmin=12+(1+2*i)+(-1)^(i);
        if Di>Dmin && Di<=Dmax && tmin>t
            t=tmin;
        end
    end
end
end
% The wind effect is considered only in the range which appears above.
% the thickness is adjusted according to standard increments.
if t<=50.8
    t=ceil(t/3.175)*3.175;
else
    t=ceil(t/6.35)*6.35;
end

%% Determination of the vessel weight without internals
We=(pi*(Di*100/2.54+t/(10*2.54))*(Lss*100/2.54+0.8*Di*100/2.54)*t/(10*2.54)*0.284)*0.454; % in kg
% On the book by Campbell appears a simpler formula but it overestimates
% the weight when Lss/Di is higher than 5 and it possibly underestimates
% the weight when Lss/Di is lower than 3
%% Determination of the weight of nozzles and internals
% If Di is lower than 0.616 m or higher than 3.234 m is out of range to
% determine the weight of internals, according to Campbell (2004) data
% Weight of internals according to the internal diameter of the vessel
if Di<0.616 || Di>3.242
    Wi = 145*pi*Di^2*0.1016/4; % Gerunda (1981) recommends to use an 
    %approximate density of 9 lb/ft3(145 kg/m3) and 4''(0.1016 m) of height of demister pad
    Wi = ceil(Wi);
else
Wi_matrix=[616 770 924 1078 1232 1386 1540 1694 1848 2002 2156 2310 2464 2618 2772 2926 3080 3234; 5 7 9 10 12 15 16 19 21 23 25 28 31 34 36 39 42 45];
[Wi,pos4]=min(abs(Wi_matrix(1,:)-Di*1000));
Wi=Wi_matrix(2,pos4);
end
% Weight of the nozzles (Wn).The software determines which nozzle weight (Wn) matrix
% DN>600 mm are out of range to compute the weight of the nozzles.
% corresponds to the ANSI class, determined before
ANSI = [150 300 600 900];

for i=1:4
    if ANSI(i)==ansi;
        j=i;
    else
        i=i+1;
    end
end
DN_array = [50 75 100 150 200 250 300 350 400 450 500 600]; % Array of the established DN for estimating Wn
% cat allows creating 3D arrangements
Wn_matrix = cat(4,[DN_array; 4 7 11 20 29 43 61 75 97 150 194 267],[DN_array; 5 11 18 32 50 66 100 129 168 277 321 513],[DN_array; 7 18 27 54 79 129 165 233 315 424 564 823],[DN_array; 13 20 34 70 118 170 249 351 437 625 767 1379]);
% Then, it will be estimate the weight of the nozzles taking into
% consideration the closest value of (DN, immediately higher)
if DN<50 || DN>600
    Wn=0.08*We; % It's an approximation made by Coulson et al (2005)
else
for i=1:4
    if i==j
[Wn,pos4]= min(abs(Wn_matrix(1,:,i)-DN));
if Wn_matrix(1,pos4,i)<DN
   Wn = Wn_matrix(2,pos4+1,i);
else
    Wn = Wn_matrix(2,pos4,i);
end
    else
        i=i+1;
    end
end
end
%% Calculation of the total vessel weight
W_tot=We+Wi+Wn; % in kg
%% Determination of the pressure drop
Kc=0.2; % Constant to determine the pressure drop
th=0.1016; % Knitted-meshi thickness in m
P_drop=Kc*(Rho_l-Rho_g)*Ks^2*th; %Pressure drop according to AlphaMIST Design Sheet in kPa
P_drop=P_drop*1E3*1E-5*1019.72*10; % Pressure drop in mm H20
%% Determination of the separator cost according to its weight.  The
% equation of Mulet et al (1981) is updated from 1978 (it corresponds to
% the vessel prices) and december 2011.
CEPCI_1978 = 219; % Chemical Engineering index (1978)
CEPCI_2011 = 590.8; % Chemical Engineering index (2011)
% The cost of the vessel (Cb) is in the range of 4876 and 226000 lb (or 2210 and 103000 kg) while
% the cost of ladders and platforms (Ca) is in the range of Di=1.83 m, Lss
% = 3.66 m and Di= 3.05, Lss = 6.1 m
Cb =(exp(8.6-0.21651*log(W_tot)+0.04576*(log(W_tot))^2))*CEPCI_2011/CEPCI_1978;
if Di<1.83 && Lss<3.66  || Di>3.05 && Lss>6.1 
   Ca =(exp(8.6-0.21651*log(0.05*W_tot)+0.04576*(log(0.05*W_tot))^2))*CEPCI_2011/CEPCI_1978;
   % When the the values for calculating platforms and ladders are
   % out-range, it is estimated that they corresponds to 5% of the weight
else
    Ca =(1017*(Di^0.7396)*(Lss^0.70684))*CEPCI_2011/CEPCI_1978;
end
Fm=1; % For other materials, it is higher.
C_Mulet = Fm*Cb + Ca;
%% Determination of purchase cost of the separator base on the eq Turton et
%al (1998).  The cost are based by prices in 1996.
% Matrix with K(Di) to calculate the base separator at 0<=P=<3.7 barg
Di_matrix=[ 0.3 0.5 1 1.5 2 2.5 3 4; 3.3392 3.4746 3.6237 3.7559 3.9484 4.0547 4.1110 4.3919; 0.5538 0.5893 0.5262 0.6361 0.4623 0.462 0.6094 0.2859; 0.2851 0.2053 0.2146 0.1069 0.1717 0.1558 0.049 0.1842];
% Linear interpolation of the Ki values according to the internal diameter
K1=interp1(Di_matrix(1,:),Di_matrix(2,:),Di);
K2=interp1(Di_matrix(1,:),Di_matrix(3,:),Di);
K3=interp1(Di_matrix(1,:),Di_matrix(4,:),Di);
%Base cost at low pressure. The variable is the length of the vessel
C_bas_Turton=10^(K1+K2*log10(Lss)+K3*(log10(Lss))^2); %Cost in $
%Determination of the pressure factor to scale up the separator for higher
%pressures.
if Pn-1<3.7
    f_pres=1;
else
f_pres=0.5146+0.6838*log10(Pn-1)+0.2927*(log10(Pn-1))^2+0.0235*(log10(Pn-1))^6+0.002*(log10(Pn-1))^8;
end
CEPCI_1996 = 382; % Chemical Engineering index (1996)
B1=2.5; B2=1.72; % Factors to determine the bare module factor
C_Turton=C_bas_Turton*(f_pres*Fm)*(CEPCI_2011/CEPCI_1996); %Approximated f.o.b value
%% Determination of the purchase cost by Seider et al (2010) eq.  Based on
% January 2007's prices.
CEPCI_2006=500;
% the range of the equation is from 4200 lb(1906 kg) to 1000000 lb (454000
% kg). Ladders and platforms are between 0.9<Di<6.4 and 3.7<Lss<12.2
C_b_Seider = (exp(7.0132+0.18255*log(W_tot/0.454)+0.02297*(log(W_tot/0.454))^2)); %W_tot is converted into lb
if Di<0.9 || Lss<6.4 || Di>6.4 || Lss>12.2
C_a_Seider = (exp(7.0132+0.18255*log(0.05*W_tot/0.454)+0.02297*(log(0.05*W_tot/0.454))^2)); % Value to corresponds to 5% of the overall weight
else
C_a_Seider = 361.8*(Di/0.3048)^0.7396*(Lss/0.3048)^0.70684; %Di and Lss in the equation are converted into ft.
end
C_Seider = (C_a_Seider + C_b_Seider)*CEPCI_2011/CEPCI_2006;
%% Determination of Vessel Purchase cost according to eq by Guthrie (1969)
MS_2011=1536.5; MS_1968=280; % Marshall & Swift index (1969 and 2011)
% The equation is in the range of 1 ft(0.305m)<D<10 ft(3.05 m) 
% and 4ft(1.2m)<Lss<100ft(30.5m)
C_Guthrie_bas = 101.9*(Di/0.3048)^1.066*(Lss/0.3048)^0.82;
C_Guthrie = (MS_2011/MS_1968)*C_Guthrie_bas*Fm*f_pres; %f_pres corresponds to the Turton (Higher than the Guthrie's)
%% Determination of the purchase cost according to Cooper (2010). The
% equation is an update of the Mulet et al (1981) based on prices of the
% first quarter of 2003. 
CEPCI_2002=396;
C_Cooper=exp(9.1-0.2889*log(W_tot/0.454)+0.04576*(log(W_tot/0.454))^2)*(CEPCI_2011/CEPCI_2002);
%% Determination of purchase cost according to Sinnot & Towler (2009)
% the equation have a range between  160 kg and 250000 kg
CEPCI_2007=509.1;
C_Sinnot=(10000+29*W_tot^0.85)*(CEPCI_2011/CEPCI_2007);
%% Determination of the demister pad (Base on the equation by Turton et al (2009))
CEPCI_2001=391;
A_demister = pi*(Di/2)^2;
Fq=3; % Factor in the case of having one stage
F_m =1.2; % Factor which depends on the material (In this case CS)
% The range of the following equation is 0.7-10.5 m2
C_demister_pad = (10^(3.2353+ 0.4838*log10(A_demister)+ 0.3434*(log10(A_demister))^2))*Fq*F_m*(CEPCI_2011/CEPCI_2001);
if A_demister>10.5
    C_demister_pad = 0.05*C_Seider;
disp('THE VESSEL IS OUT OF RANGE TO COMPUTE DEMISTER PAD COST')
end
if C_demister_pad/C_Sinnot>0.25
C_demister_pad = 0.25*C_Sinnot; % An approximation based on the maximum value registered at low pressure for A_pad=0.7m2
disp('THE VESSEL IS OUT OF RANGE TO COMPUTE DEMISTER PAD COST')
end

%% Determination of the vessel cost including installation
C_Seider_bm = (C_Seider+C_demister_pad)*(B2+B1/(Fm*f_pres)); % Bare Module cost using the Seider Formula. FBM are based on low pressure, so it should be corrected as shown in the formula
C_Turton_bm = (C_bas_Turton+C_demister_pad)*(B1+B2*f_pres*Fm)*(CEPCI_2011/CEPCI_1996);
C_Guthrie_bm = (C_Guthrie_bas+C_demister_pad)*(B1+B2*f_pres*Fm)*(MS_2011/MS_1968); % Using the Turton et al's FBM factor
C_Sinnot_bm = (C_Sinnot+C_demister_pad)*(B2+B1/(Fm*f_pres));
%% Use of just one equation for purchase and bare module costs
if W_tot<1906 && P<=40|| W_tot<1906 && Di<0.3
    C_vessel=C_Sinnot;
    C_bm=C_Sinnot_bm;
    if W_tot<1906 && P>40
        C_vessel=C_Guthrie;
        C_bm=C_Guthrie_bm;
    end
else
   C_vessel=C_Seider;
   C_bm=C_Seider_bm;
end
C_fob=C_vessel+C_demister_pad;
%% Summary of the vessel dimensions, f.o.b 
disp('       GAS SCRUBBER DIMENSIONS         ');  
disp([' The diameter of the vessel (in m) is:  ',num2str(Di,3)]);
disp([' The height of the vessel (in m) is:    ',num2str(Lss,3)]);
disp([' The thickness of the vessel (in mm) is:   ', num2str(t,3)]);
disp([' The weight of the vessel (in kg) is:    ', num2str(W_tot,6)]);
disp([' The gas load factor (in m/s) is:     ', num2str(Ks,3)])
disp([' The pressure drop across the wire mesh (in mm H2O) is:    ', num2str(P_drop,4)]);
disp('   F.O.B VESSEL COST in US$   ');
if Di<0.616 || Di> 3.234 || DN>600
    disp('THE WEIGHT OF DEMISTER PAD AND/OR NOZZLES CORRESPONDS TO AN APPROXIMATION')
end
if W_tot>=160 && W_tot<=454000 
    if Di<0.9 || Di>6.4 || Lss<3.7 || Lss>12.2
       disp('THE COST OF LADDERS AND PLATFORMS IS A ROUGHT APPROXIMATION')
    end
disp(['The approximate purchase vessel cost($):  ', num2str(C_vessel,7)]);
disp(['The approximate cost of the demister pad (Including installation) ($):   ',num2str(C_demister_pad,5)]);
disp(['The approximate purchase knitted-mesh scrubber cost($):  ', num2str(C_fob,7)]);
else
    disp('THE VESSEL IS OUT OF RANGE ACCORDING TO SEIDER EQ (2010)')
end
%% BARE MODULE VESSEL COST
disp(' BARE MODULE VESSEL COST (in US$), EXCLUDING INTERNATIONAL FREIGHT AND CONTINGENCIES,  ');

if W_tot>=160 && W_tot<=4540000
disp(['The approximate bare module cost ($):  ', num2str(C_bm, 7)]);
end

f_pres
Pn




        
    



 